@@ -194,10 +194,6 @@ def from_x1dints(rainbow, filepath):
         where `x` is the Rainbow you just created.
         """
         warnings.warn(message)
-    else:
-        # kludge to replace zero uncertainties
-        if np.all(rainbow.uncertainty == 0):
-            rainbow.fluxlike["uncertainty"] = np.ones_like(rainbow.fluxlike["flux"])
 
     # try to guess wscale (and then kludge and call it linear)
     # rainbow._guess_wscale()
